@@ -244,7 +244,7 @@
   .cmd <- rxode2::rxGetControl(.ui, "runCommand", "")
   if (checkmate::testFileExists(.qs)) {
     .minfo("load saved nlmixr2 object")
-    .ret <- qs::qread(.qs)
+    .ret <- qs2::qs_read(.qs)
     if (!exists("parHistData", .ret$env)) {
       .tmp <- .ret$ui$monolixParHistory
       if (is.null(.tmp)) {
@@ -253,7 +253,7 @@
         .tmp$type <- "Unscaled"
         assign("parHistData", .tmp, .ret$env)
         .minfo("monolix parameter history integrated into fit object")
-        qs::qsave(.ret, .qs)
+        qs2::qs_save(.ret, .qs)
       }
     }
     return(.ret)
@@ -329,9 +329,9 @@
       .tmp$type <- "Unscaled"
       assign("parHistData", .tmp, .ret$env)
       .minfo("monolix parameter history integrated into fit object")
-      qs::qsave(.ret, .qs)
+      qs2::qs_save(.ret, .qs)
     }
-    qs::qsave(.ret, .qs)
+    qs2::qs_save(.ret, .qs)
   }
   return(.ret)
 }
